@@ -16,6 +16,7 @@
 # limitations under the License.
 
 import contextlib
+import platform
 import subprocess
 from textwrap import dedent
 
@@ -63,6 +64,17 @@ class TestDepends(TestCase):
         mock_checkoutput.assert_called_once_with(["lsb_release", "-cirs"],
                                                  stderr=subprocess.STDOUT)
 
+    @contextlib.contextmanager
+    def _mock_platform_darwin(self, system):
+        r_val = system
+        mock_checkoutput = self.useFixture(
+            fixtures.MockPatchObject(
+                platform,
+                'system',
+                return_value=r_val)).mock
+        yield mock_checkoutput
+        mock_checkoutput.assert_called_once_with()
+
     def test_detects_amazon_linux(self):
         with self._mock_lsb("AmazonAMI"):
             depends = Depends("")
@@ -76,6 +88,12 @@ class TestDepends(TestCase):
             self.assertThat(platform_profiles, Contains("platform:centos"))
             self.assertThat(platform_profiles, Contains("platform:redhat"))
 
+    def test_detects_darwin(self):
+        with self._mock_platform_darwin("Darwin"):
+            depends = Depends("")
+            platform_profiles = depends.platform_profiles()
+            self.assertThat(platform_profiles, Contains("platform:darwin"))
+
     def test_detects_rhel(self):
         with self._mock_lsb("RedHatEnterpriseServer"):
             depends = Depends("")
@@ -90,6 +108,20 @@ class TestDepends(TestCase):
                 platform_profiles,
                 Contains("platform:redhat"))
 
+    def test_detects_rhel_workstation(self):
+        with self._mock_lsb("RedHatEnterpriseWorkstation"):
+            depends = Depends("")
+            platform_profiles = depends.platform_profiles()
+            self.assertThat(
+                platform_profiles,
+                Contains("platform:redhatenterpriseworkstation"))
+            self.assertThat(
+                platform_profiles,
+                Contains("platform:rhel"))
+            self.assertThat(
+                platform_profiles,
+                Contains("platform:redhat"))
+
     def test_detects_fedora(self):
         with self._mock_lsb("Fedora"):
             depends = Depends("")
@@ -110,12 +142,10 @@ class TestDepends(TestCase):
             self.assertThat(platform_profiles,
                             Contains("platform:suse"))
 
-    def test_detects_opensuse_tumbleweed(self):
-        with self._mock_lsb("openSUSE Tumbleweed"):
+    def test_detects_opensuse(self):
+        with self._mock_lsb("openSUSE"):
             depends = Depends("")
             platform_profiles = depends.platform_profiles()
-            self.assertThat(platform_profiles,
-                            Contains("platform:opensusetumbleweed"))
             self.assertThat(platform_profiles,
                             Contains("platform:opensuse"))
             self.assertThat(platform_profiles,
@@ -181,8 +211,8 @@ class TestDepends(TestCase):
                 depends.platform_profiles(), Contains("platform:rpm"))
             self.assertIsInstance(depends.platform, Rpm)
 
-    def test_opensuse_tumbleweed_implies_rpm(self):
-        with self._mock_lsb("openSUSE Tumbleweed"):
+    def test_opensuse_implies_rpm(self):
+        with self._mock_lsb("openSUSE"):
             depends = Depends("")
             self.assertThat(
                 depends.platform_profiles(), Contains("platform:rpm"))
